/***********************************************************
 * $Id: OldSerialVersionUID.java 70 2009-05-13 08:05:13Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 20.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * This annotation adds a compatibility note for an old serial version UID
 * for the compact Marshaler.
 * 
 * @author wglas
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.TYPE})
public @interface OldSerialVersionUID {

    /**
     * @return the old serialVersionUID.
     */
    abstract long id();
    
    /**
     * @return The fields which have been added to the class since the
     *         given serialVersion UID.
     */
    abstract String[] skipFields();
    
    /**
     * @return The serialVersionUID of the super class, if the old version of this
     *         class had an old version of the super class.
     *         The argument will be passed to {@link Long#valueOf(String)} if not
     *         empty. In this case, the super class must have an
     *         {@link OldSerialVersionUID} annotation for the given serialVersionUID. 
     */
    abstract String superSerialVersionUID() default "";
}
