/***********************************************************
 * $Id: OpenClientSessionInterceptor.java 195 2010-09-06 06:08:19Z remoting $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 29.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.beans;

import org.aopalliance.intercept.MethodInterceptor;
import org.aopalliance.intercept.MethodInvocation;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.clazzes.remoting.client.ClientManager;

/**
 * This interceptor binds a remote session and a client to the current thread up to
 * the end of a method invocation.
 *
 * In order to use this class you need to use the optional spring dependency or
 * use aopalliance-1.0
 */
public class OpenClientSessionInterceptor implements MethodInterceptor {

    private static final Log log = LogFactory.getLog(OpenClientSessionInterceptor.class);

    public static final String DEFAULT_SESSION_CONTEXT_SUBSYTEM = "sessionContext";

    private String sessionContextSubSystem = DEFAULT_SESSION_CONTEXT_SUBSYTEM;

    private ClientManager clientManager;
    private SessionAuthenticator sessionAuthenticator;

    /* (non-Javadoc)
     * @see org.aopalliance.intercept.MethodInterceptor#invoke(org.aopalliance.intercept.MethodInvocation)
     */
    public Object invoke(MethodInvocation invocation) throws Throwable {
       
        if (log.isDebugEnabled())
            log.debug("Opening client session context for call ["+invocation+"].");

        ClientHolder.openContext(this.clientManager,
                this.sessionContextSubSystem,
                this.sessionAuthenticator);
        
		try {
        	
            Object ret = invocation.proceed();
            return ret;
        }
        finally {
        	
            if (log.isDebugEnabled())
                log.debug("Closiing client session context for call ["+invocation+"].");

            ClientHolder.closeContext(this.clientManager,this.sessionContextSubSystem);
        }
    }

	/**
	 * @return the clientManager
	 */
	public ClientManager getClientManager() {
		return this.clientManager;
	}

	/**
	 * @param clientManager the clientManager to set
	 */
	public void setClientManager(ClientManager clientManager) {
		this.clientManager = clientManager;
	}

	/**
	 * @return the sessionContextSubSystem
	 */
	public String getSessionContextSubSystem() {
		return this.sessionContextSubSystem;
	}

	/**
	 * @param sessionContextSubSystem the sessionContextSubSystem to set
	 */
	public void setSessionContextSubSystem(String sessionContextSubSystem) {
		this.sessionContextSubSystem = sessionContextSubSystem;
	}

	/**
	 * @return The authenticator used to generate authentication metadata for the server.
	 */
	public SessionAuthenticator getSessionAuthenticator() {
		return this.sessionAuthenticator;
	}

	/**
	 * @param sessionAuthenticator The session authenticator to set.
	 */
	public void setSessionAuthenticator(SessionAuthenticator sessionAuthenticator) {
		this.sessionAuthenticator = sessionAuthenticator;
	}
}
