/***********************************************************
 * $Id: Cmd.java 88 2009-07-26 17:43:20Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 15.10.2008
 * 
 ***********************************************************/

package org.clazzes.remoting.cmd;

import java.io.Serializable;

/**
 * An on-the-wire  wire command of the remoting system with a visitor.
 * 
 * @author wglas
 */
public abstract class Cmd implements Serializable {

    private static final long serialVersionUID = 4639537525936918825L;

    /**
     * @param visitor The visitor representing a polymorphic operation on the command.
     */
    public abstract void accept (CmdVisitor visitor);
   
    /**
     * Check for object being a Cmd instance and accept the given visitor.
     * Throws a {@link ClassCastException} if the object is invalid.
     * 
     * @param obj The deserialized object to check.
     * @param visitor The visitor being accepted.
     */
    public static void acceptCmd(Object obj, CmdVisitor visitor) {
        
        if (obj instanceof Cmd)
            ((Cmd)obj).accept(visitor);
        
        else
            throw new ClassCastException("The received object ["+obj+"] is not a remoting command.");
    }
}
