/***********************************************************
 * $Id: ClassBytes.java 139 2009-10-01 14:16:18Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 19.10.2008
 * 
 ***********************************************************/

package org.clazzes.remoting.loading;

/**
 * A ClassBytes instance is used to transfer a compiled class over the wire.
 */
public class ClassBytes implements java.io.Serializable
{
   static final long serialVersionUID = 9163990179051656161L;
   private final String className;
   private final byte[] classBytes;

   /**
    * Construct a ClassBytes instance.
    * 
    * @param className The dot-separated name of the class.
    * @param bytes The content of the compiled class file.
    */
   public ClassBytes(String className, byte bytes[]) {
       
      this.className = className;
      this.classBytes = bytes;
   }

   public String toString() {
       return "ClassBytes[" + this.className + ";"+this.classBytes.length+"bytes]";
   }

   /**
    * @return The dot-separated name of the class.
    */
   public String getClassName()  {
       return this.className;
   }

   /**
    * @return
    */
   public byte[] getClassBytes() {
       return this.classBytes;
   }
}
