/***********************************************************
 * $Id: ObjectResolver.java 144 2009-10-12 07:47:02Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 17.08.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.marshal;

import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

/**
 * An object resolver is used to replace objects before being written to
 * the stream or after being read from the stream.
 * 
 * It thus accomplishes the same tasks like
 * {@link ObjectOutputStream#enableReplaceObject(boolean)} and
 * {@link ObjectInputStream#enableResolveObject(boolean)} for marshalers,
 * which are not based on {@link ObjectInputStream} and {@link ObjectOutputStream}.
 */
public interface ObjectResolver {

    /**
     * Replace an object read from a stream by another one. 
     * @param obj The object, which has just been received from the stream. 
     * @return The object to return to the user.
     */
    public Object resolveRead(Object obj);
    
    /**
     * Replace an object, which is referenced in the stream before
     * {@link #resolveRead(Object)} has been called. This situation happens
     * When the original object is referenced from another object which
     * is read as part of the properties of the original object.
     * 
     * JAVA's {@link ObjectOutputStream} returns the unresolved object in this
     * situation. If the implementation of this method returns something different
     * from the passed object <code>obj</code>, this behavior my be overwritten. 
     * 
     * @param obj The object, which is currently being received from the stream.
     * @return The object to return to the user.
     */
    public Object resolvePrematureRead(Object obj);
    
    /**
     * Replace an object before being written to the stream.
     * @param obj The object to be replaced.
     * @return The object to be written instead.
     */
    public Object replaceWrite(Object obj);
}
