/***********************************************************
 * $Id: DoubleFieldMarshaler.java 60 2009-04-24 22:09:39Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 17.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.marshal.impl;

import java.io.IOException;


/**
 * This field marshaler reads/writes double fields.
 * 
 * @author wglas
 */
class DoubleFieldMarshaler extends FieldMarshaler {

    public DoubleFieldMarshaler() {
        super();
    }

    /* (non-Javadoc)
     * @see org.clazzes.remoting.marshal.impl.FieldMarshaler#readField(java.io.DataInputStream, org.clazzes.remoting.marshal.impl.MarshalerContext, java.lang.Object)
     */
    @Override
    public void readField(final CompactMarshaler context, final Object obj) throws IllegalArgumentException, IllegalAccessException, IOException {
        
        int tag = super.readTag(context);
        
        if (DOUBLE_STREAM_ID != tag)
            throw new IllegalArgumentException("Invalid tag ["+tag+
                    "] found when reading double field ["+this.field.getName()+"]"); 
        
        this.field.setDouble(obj,context.getDataInputStream().readDouble());
    }

    /* (non-Javadoc)
     * @see org.clazzes.remoting.marshal.impl.FieldMarshaler#writeField(java.io.DataOutputStream, org.clazzes.remoting.marshal.impl.MarshalerContext, java.lang.Object)
     */
    @Override
    public void writeField(final CompactMarshaler context, final Object obj) throws IOException, IllegalArgumentException, IllegalAccessException {
        
        context.getDataOutputStream().write(DOUBLE_STREAM_ID);
        context.getDataOutputStream().writeDouble(this.field.getDouble(obj));
    }

}
