/***********************************************************
 * $Id: StackTraceFieldMarshaler.java 199 2010-09-06 14:33:40Z remoting $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 06.09.2010
 * 
 ***********************************************************/

package org.clazzes.remoting.marshal.impl;

import java.io.IOException;
import java.lang.reflect.Field;

/**
 * This field marshaler handles the peculiarities with the lazily initialized
 * statckTRace field of the Throwable class.
 */
public class StackTraceFieldMarshaler extends ObjectFieldMarshaler {

    protected static final Field THROWABLE_STACK_TRACE_FIELD;
    
    static {
        
        try {
            THROWABLE_STACK_TRACE_FIELD = Throwable.class.getDeclaredField("stackTrace");
        } catch (Exception e) {

            throw new RuntimeException("Cannot find field [stackTrace] in Throwable.class",e);
        }
    }
    
    StackTraceFieldMarshaler() {
        super(THROWABLE_STACK_TRACE_FIELD);
    }
    
    @Override
    public void writeField(CompactMarshaler context, Object obj)
            throws IOException, IllegalArgumentException,
            IllegalAccessException, ClassNotFoundException {
        
        writeObject(context,((Throwable)obj).getStackTrace());
    }

}
