/***********************************************************
 * $Id: MetaHandshakeCompletedListener.java 54 2009-04-16 16:45:08Z wglas $
 * 
 * remoting framework of the clazzes project.
 * http://www.clazzes.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Created: 16.04.2009
 * 
 ***********************************************************/

package org.clazzes.remoting.transport;

import java.util.Map;

import javax.net.ssl.HandshakeCompletedEvent;
import javax.net.ssl.HandshakeCompletedListener;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.clazzes.remoting.InvocationHandler;

/**
 * This SSL handshake listener adds the SSL Session to the connection metadata
 * under the key {@link SocketMetaData#SSL_SESSION}
 * 
 * @author wglas
 */
public class MetaHandshakeCompletedListener implements
        HandshakeCompletedListener {

    private static final Log log = LogFactory.getLog(MetaHandshakeCompletedListener.class);
    
    private final Map<String,Object> meta;
    
    /**
     * @param meta The connection metadata map as passed to
     *   {@link InvocationHandler#invoke(org.clazzes.remoting.InvocationContext, Object, Map)}
     *   as part of the metadata argument.
     */
    public MetaHandshakeCompletedListener(final Map<String,Object> meta) {
        super();
        this.meta = meta;
    }

    /* (non-Javadoc)
     * @see javax.net.ssl.HandshakeCompletedListener#handshakeCompleted(javax.net.ssl.HandshakeCompletedEvent)
     */
    public void handshakeCompleted(HandshakeCompletedEvent event) {
        
        if (log.isDebugEnabled())
            log.debug("Adding SSL session ["+event.getSession()+"] to connection metadata.");
            
        this.meta.put(SocketMetaData.SSL_SESSION,event.getSession());
    }

}
